---
name: '🐛 Bug report'
about: Report a bug encountered while operating
title: ''
labels: '🐛 bug'
assignees: ''
---

<!-- Please use this template while reporting a bug and provide as much info as possible. Not doing so may result in your bug not being addressed in a timely manner. Thanks!

-->

**What happened**:

**What you expected to happen**:

**How to reproduce it (as minimally and precisely as possible)**:

**Anything else we need to know?**:

**Environment and application version**:
